@@ -6,12 +6,6 @@
 
 #include <Rcpp.h>
 
-// Defined since R 3.1.0, according to Tomas Kalibera, but there's no reason to break
-// compatibility with 3.0.x
-#ifndef MAYBE_SHARED
-#define MAYBE_SHARED(x) (NAMED(x) > 1)
-#endif
-
 #else
 
 #define R_NegInf -INFINITY
